@@ -31,8 +31,7 @@
 
 (defun mew-cache-dinfo-get-decode-broken (buf)
   (when buf
-    (save-excursion
-      (set-buffer buf)
+    (with-current-buffer buf
       (mew-cinfo-get-decode-broken))))
 
 (defvar mew-xinfo-list
@@ -42,7 +41,7 @@
 (mew-blinfo-defun 'mew-xinfo mew-xinfo-list)
 
 (defun mew-xinfo-copy (buf)
-  (set 'mew-xinfo (save-excursion (set-buffer buf) (symbol-value 'mew-xinfo))))
+  (set 'mew-xinfo (with-current-buffer buf (symbol-value 'mew-xinfo))))
 
 (defun mew-xinfo-clear ()
   (set 'mew-xinfo nil))
@@ -53,7 +52,7 @@
 ;;
 
 (defun mew-cache-decode-syntax (buf)
-  (save-excursion (set-buffer buf) mew-decode-syntax))
+  (with-current-buffer buf mew-decode-syntax))
 
 (defvar mew-cache nil
   "A list of decoded messages cache.
@@ -88,8 +87,7 @@ If MUST-HIT is non-nil and no valid cache entry is found, an error occurs."
 	(error "%s does not exist" (mew-concat-folder fld msg)))
       (setq time (mew-file-get-time file))
       (setq size (mew-file-get-size file))
-      (save-excursion
-	(set-buffer cache)
+      (with-current-buffer cache
 	(setq ok (mew-cinfo-equal fld msg time size)))
       (if ok
 	  (progn
@@ -236,7 +234,7 @@ if decode fails."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2009 Mew developing team.
+;; Copyright (C) 1997-2011 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
