@@ -43,7 +43,7 @@ Execute mew-dinfo-set before calling this."
   (mew-header-setup-decoration)
   (mew-draft-mode-name 'header)
   (force-mode-line-update)
-  (run-hooks 'mew-header-mode-hook)
+  (mew-run-mode-hooks 'mew-header-mode-hook)
   ;; auto-fill-function is set by mew-header-mode-hook
   (when auto-fill-function
     (make-local-variable 'auto-fill-function)
@@ -125,8 +125,7 @@ by a header re-write."
 	(mew-current-get-window-config)
 	(mew-redraw)
 	(save-excursion
-	  (save-window-excursion
-	    (set-buffer buf)
+	  (with-current-buffer buf
 	    (mew-encode-make-backup)
 	    (mew-header-clear)
 	    ;; the end of the header
@@ -174,8 +173,7 @@ by a header re-write."
 	(mew-current-get-window-config)
 	(mew-redraw)
 	(save-excursion
-	  (save-window-excursion
-	    (set-buffer buf)
+	  (with-current-buffer buf
 	    (mew-encode-make-backup)
 	    (mew-header-clear)
 	    ;; the end of the header
@@ -890,9 +888,8 @@ mew-summary-reedit."
     ;; De-compose the message in the burst buffer.
     ;; do not decode Message/Rfc822 parts.
     ;; They will be just a attachment message.
-    (save-excursion
+    (with-current-buffer buf
       ;; Let's decode the message without limitations
-      (set-buffer buf)
       (mew-erase-buffer)
       (mew-insert-message fld msg mew-cs-text-for-read nil)
       (mew-dinfo-set (1+ (length part)) 'no-cs-conv t alt 'encap-html)
@@ -1174,7 +1171,7 @@ mew-summary-reedit."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2009 Mew developing team.
+;; Copyright (C) 1999-2011 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
