@@ -250,8 +250,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 
 (defun mew-pgp-debug (label string)
   (when (mew-debug 'pgp)
-    (save-excursion
-      (set-buffer (get-buffer-create mew-buffer-debug))
+    (with-current-buffer (get-buffer-create mew-buffer-debug)
       (goto-char (point-max))
       (insert (format "\n<%s>\n%s\n" label string)))))
 
@@ -930,8 +929,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
      (let ((fld (mew-summary-folder-name))
 	   (msg (mew-summary-message-number2))
 	   type)
-       (save-excursion
-	 (set-buffer (mew-buffer-message))
+       (with-current-buffer (mew-buffer-message)
 	 ;; We need MIME-decoded buffer to check PGP boundaries.
 	 (setq type (mew-old-pgp-check))
 	 (if type
@@ -1078,8 +1076,7 @@ public keyring."
       (message "PGP not found")
     (when (y-or-n-p "Add this PGP key onto your public keyring? ")
       (setq mew-pgp-tmp-file (mew-make-temp-name))
-      (save-excursion
-	(set-buffer cache)
+      (with-current-buffer cache
 	(mew-frwlet mew-cs-dummy mew-cs-autoconv
 	  (write-region begin end mew-pgp-tmp-file nil 'no-msg))
 	(set-buffer (mew-buffer-message))
@@ -1101,8 +1098,8 @@ public keyring."
 	   (insert "\"pgp -ke\" and \"pgp -ks\" to change them.\n"))
 	  ((eq mew-pgp-ver mew-pgp-ver5)
 	   (insert "\"pgpk -e\" and \"pgpk -s\" to change them.\n"))
- 	  ((eq mew-pgp-ver mew-pgp-ver6)
- 	   (insert "\"pgp -ke\" and \"pgp -ks\" to change them.\n"))
+	  ((eq mew-pgp-ver mew-pgp-ver6)
+	   (insert "\"pgp -ke\" and \"pgp -ks\" to change them.\n"))
 	  ((eq mew-pgp-ver mew-pgp-verg)
 	   (insert "\"gpg --edit-key\" to change them.\n")))
 	 (insert "If you do not know what TRUST and VALIDITY is,\n"
@@ -1118,8 +1115,7 @@ public keyring."
 
 (defun mew-pgp-fetch-key-by-xuri ()
   (let (val uri)
-    (save-excursion
-      (set-buffer (mew-buffer-message))
+    (with-current-buffer (mew-buffer-message)
       (catch 'loop
 	(dolist (key mew-x-pgp-key-list)
 	  (setq val (mew-header-get-value key))
@@ -1144,8 +1140,7 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
   (if arg
       (mew-pgp-fetch-key-by-xuri)
     (let (keyid userid xmew)
-      (save-excursion
-	(set-buffer (mew-buffer-message))
+      (with-current-buffer (mew-buffer-message)
 	(setq userid (mew-header-parse-address mew-from:))
 	(setq xmew (mew-header-get-value mew-x-mew:)))
       (cond
@@ -1185,9 +1180,8 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
 
 (defun mew-pgp-fetch-process-sentinel (process event)
   (message "PGP key fetching...done")
-  (let* ((buf (process-buffer process)))
-    (save-excursion
-      (set-buffer buf)
+  (let ((buf (process-buffer process)))
+    (with-current-buffer buf
       (goto-char (point-min))
       (if (and (search-forward mew-pgp-key-begin nil t)
 	       (search-forward mew-pgp-key-end nil t))
@@ -1202,11 +1196,11 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
 ;; You do not have the secret key needed to decrypt this file.
 ;;
 ;;    <Verify> <2>
-;; 	Keyring file 'pubring.pgp' does not exist.
-;; 	Enter public key filename:
+;;	Keyring file 'pubring.pgp' does not exist.
+;;	Enter public key filename:
 ;;
-;; 	Key matching expected Key ID 1B8BF431 not found in file 'pubring.pgp'.
-;; 	Enter public key filename:
+;;	Key matching expected Key ID 1B8BF431 not found in file 'pubring.pgp'.
+;;	Enter public key filename:
 ;;
 ;; <Sign> <1>
 ;;
@@ -1233,7 +1227,7 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2009 Mew developing team.
+;; Copyright (C) 1994-2011 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
