@@ -724,8 +724,7 @@
 	  (setq virtual (mew-net-virtual-info-get-virtual virtual-info))
 	  (when virtual
 	    (mew-pop-set-status-buf pnm virtual)
-	    (save-excursion
-	      (set-buffer virtual)
+	    (with-current-buffer virtual
 	      (mew-summary-lock process "POPing" (or sshpro sslpro)))))
 	 ((eq directive 'scan)
 	  (mew-pop-set-range pnm (nth 0 args))
@@ -753,8 +752,7 @@
 
 (defun mew-pop-debug (label string)
   (when (mew-debug 'net)
-    (save-excursion
-      (set-buffer (get-buffer-create mew-buffer-debug))
+    (with-current-buffer (get-buffer-create mew-buffer-debug)
       (goto-char (point-max))
       (insert (format "\n<%s>\n%s\n" label string)))))
 
@@ -817,7 +815,7 @@
 	 (hlds (mew-pop-get-hlds pnm))
 	 (uidl (mew-pop-get-uidl pnm))
 	 (done (mew-pop-get-done pnm))
- 	 (error (mew-pop-get-error pnm))
+	 (error (mew-pop-get-error pnm))
 	 (file (mew-expand-file bnm mew-pop-msgid-file))
 	 (buf (process-buffer process))
 	 (virtual-info (mew-pop-get-virtual-info pnm))
@@ -890,7 +888,7 @@
 	 ((eq directive 'scan)
 	  (mew-biff-clear)
 	  (cond
-	   ((= rttl 0)
+	   ((or (= rttl 0) (null uidl))
 	    (mew-pop-message pnm "No messages scanned"))
 	   ((= rttl 1)
 	    (mew-pop-message pnm "1 message scanned")
@@ -941,8 +939,7 @@
 	 (tag (mew-pop-passtag2 case))
 	 passwd)
     (when (get-buffer case:inbox)
-      (save-excursion
-	(set-buffer case:inbox)
+      (with-current-buffer case:inbox
 	(when (and (mew-summary-exclusive-p 'no-msg)
 		   (and (or mew-use-cached-passwd mew-use-master-passwd)
 			(setq passwd (mew-passwd-get-passwd tag))))
@@ -955,8 +952,7 @@
 	 (inbox (mew-proto-inbox-folder nil case))
 	 (case:inbox (mew-case-folder case inbox)))
     (when (get-buffer case:inbox)
-      (save-excursion
-	(set-buffer case:inbox)
+      (with-current-buffer case:inbox
 	(when (mew-summary-exclusive-p)
 	  (mew-pop-retrieve case 'biff case:inbox))))))
 
@@ -964,7 +960,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2009 Mew developing team.
+;; Copyright (C) 1999-2011 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
